@@ -1,12 +1,12 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2015-03-04'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2015-04-09'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 #use Complete;
 
@@ -600,7 +600,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.30 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-03-04.
+This document describes version 0.31 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-04-09.
 
 =head1 SYNOPSIS
 
